@@ -2,7 +2,7 @@ package Mojolicious::Plugin::Narada;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.0.1';
 
 use MojoX::Log::Fast;
 use Narada::Config qw( get_config get_config_line );
@@ -107,7 +107,7 @@ Mojolicious::Plugin::Narada - Narada configuration plugin
 
 =head1 VERSION
 
-This document describes Mojolicious::Plugin::Narada version v1.0.0
+This document describes Mojolicious::Plugin::Narada version v1.0.1
 
 
 =head1 SYNOPSIS
@@ -193,7 +193,6 @@ guarantee their consistency in any environment:
 
 =back
 
-
 These config files automatically loaded from C<config/hypnotoad/*>
 and used to initialize C<< $app->config(hypnotoad) >>:
 
@@ -223,6 +222,17 @@ L<Mojolicious::Plugin::Narada> supports the following options.
 Value for L<MojoX::Log::Fast>->new().
 
 
+=head1 HELPERS
+
+=head2 proxy
+
+=head2 weak_proxy
+
+    $cb = $app->proxy( $cb );
+    $cb = $c->proxy( $cb );
+    $cb = $c->weak_proxy( $cb );
+
+
 =head1 METHODS
 
 L<Mojolicious::Plugin::Narada> inherits all methods from
@@ -293,7 +303,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2013- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
